@@ -1,13 +1,10 @@
 /******************************************************************************
  *
- * 
- *
- *
- * Copyright (C) 1997-2015 by Dimitri van Heesch.
+ * Copyright (C) 1997-2021 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -16,28 +13,28 @@
  *
  */
 
-#ifndef _LATEXDOCVISITOR_H
-#define _LATEXDOCVISITOR_H
+#ifndef LATEXDOCVISITOR_H
+#define LATEXDOCVISITOR_H
 
+#include <stack>
+
+#include "qcstring.h"
 #include "docvisitor.h"
-#include <qstack.h>
-#include <qcstring.h>
-#include <qlist.h>
 
-class FTextStream;
-class CodeOutputInterface;
+class LatexCodeGenerator;
+class TextStream;
 
 /*! @brief Concrete visitor implementation for LaTeX output. */
 class LatexDocVisitor : public DocVisitor
 {
   public:
-    LatexDocVisitor(FTextStream &t,CodeOutputInterface &ci,
-                    const char *langExt,bool insideTabbing);
-    
+    LatexDocVisitor(TextStream &t,LatexCodeGenerator &ci,
+                    const QCString &langExt,bool insideTabbing);
+
     //--------------------------------------
     // visitor functions for leaf nodes
     //--------------------------------------
-    
+
     void visit(DocWord *);
     void visit(DocLinkedWord *);
     void visit(DocWhiteSpace *);
@@ -59,7 +56,7 @@ class LatexDocVisitor : public DocVisitor
     //--------------------------------------
     // visitor functions for compound nodes
     //--------------------------------------
-    
+
     void visitPre(DocAutoList *);
     void visitPost(DocAutoList *);
     void visitPre(DocAutoListItem *);
@@ -128,8 +125,6 @@ class LatexDocVisitor : public DocVisitor
     void visitPost(DocXRefItem *);
     void visitPre(DocInternalRef *);
     void visitPost(DocInternalRef *);
-    void visitPre(DocCopy *);
-    void visitPost(DocCopy *);
     void visitPre(DocText *);
     void visitPost(DocText *);
     void visitPre(DocHtmlBlockQuote *);
@@ -143,7 +138,7 @@ class LatexDocVisitor : public DocVisitor
 
     struct ActiveRowSpan
     {
-      ActiveRowSpan(DocHtmlCell *c,int rs,int cs,int col) 
+      ActiveRowSpan(DocHtmlCell *c,int rs,int cs,int col)
         : cell(c), rowSpan(rs), colSpan(cs), column(col) {}
       DocHtmlCell *cell;
       int rowSpan;
@@ -151,124 +146,120 @@ class LatexDocVisitor : public DocVisitor
       int column;
     };
 
-    typedef QList<ActiveRowSpan> RowSpanList;
+    typedef std::vector<ActiveRowSpan> RowSpanList;
 
     //--------------------------------------
-    // helper functions 
+    // helper functions
     //--------------------------------------
-    
-    void filter(const char *str);
+
+    void filter(const QCString &str);
     void startLink(const QCString &ref,const QCString &file,
                    const QCString &anchor,bool refToTable=FALSE);
     void endLink(const QCString &ref,const QCString &file,
                  const QCString &anchor,bool refToTable=FALSE);
     QCString escapeMakeIndexChars(const char *s);
     void startDotFile(const QCString &fileName,const QCString &width,
-                      const QCString &height, bool hasCaption);
+                      const QCString &height, bool hasCaption,
+                      const QCString &srcFile,int srcLine);
     void endDotFile(bool hasCaption);
 
     void startMscFile(const QCString &fileName,const QCString &width,
-                      const QCString &height, bool hasCaption);
+                      const QCString &height, bool hasCaption,
+                      const QCString &srcFile,int srcLine);
     void endMscFile(bool hasCaption);
     void writeMscFile(const QCString &fileName, DocVerbatim *s);
 
     void startDiaFile(const QCString &fileName,const QCString &width,
-                      const QCString &height, bool hasCaption);
+                      const QCString &height, bool hasCaption,
+                      const QCString &srcFile,int srcLine);
     void endDiaFile(bool hasCaption);
     void writeDiaFile(const QCString &fileName, DocVerbatim *s);
     void writePlantUMLFile(const QCString &fileName, DocVerbatim *s);
 
-    void pushEnabled();
-    void popEnabled();
-
     //--------------------------------------
     // state variables
     //--------------------------------------
 
-    FTextStream &m_t;
-    CodeOutputInterface &m_ci;
+    TextStream &m_t;
+    LatexCodeGenerator &m_ci;
     bool m_insidePre;
     bool m_insideItem;
     bool m_hide;
     bool m_hideCaption;
     bool m_insideTabbing;
-    QStack<bool> m_enabled;
     QCString m_langExt;
 
     struct TableState
     {
-      TableState() : numCols(0), currentColumn(0), inRowSpan(FALSE), 
-                     inColSpan(FALSE), firstRow(FALSE)
-      { rowSpans.setAutoDelete(TRUE); }
       RowSpanList rowSpans;
-      int  numCols;
-      int currentColumn;
-      bool inRowSpan;
-      bool inColSpan;
-      bool firstRow;
+      int  numCols = 0;
+      int currentColumn = 0;
+      bool inRowSpan = false;
+      bool inColSpan = false;
+      bool firstRow = false;
     };
-    QStack<TableState> m_tableStateStack; // needed for nested tables
+    std::stack<TableState> m_tableStateStack; // needed for nested tables
     RowSpanList m_emptyRowSpanList;
 
     void pushTableState()
     {
-      m_tableStateStack.push(new TableState);
+      m_tableStateStack.push(TableState());
     }
     void popTableState()
     {
-      delete m_tableStateStack.pop();
+      m_tableStateStack.pop();
     }
     int currentColumn() const
     {
-      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->currentColumn : 0;
+      return !m_tableStateStack.empty() ? m_tableStateStack.top().currentColumn : 0;
     }
     void setCurrentColumn(int col)
     {
-      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->currentColumn = col;
+      if (!m_tableStateStack.empty()) m_tableStateStack.top().currentColumn = col;
     }
     int numCols() const
     {
-      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->numCols : 0;
+      return !m_tableStateStack.empty() ? m_tableStateStack.top().numCols : 0;
     }
     void setNumCols(int num)
     {
-      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->numCols = num;
+      if (!m_tableStateStack.empty()) m_tableStateStack.top().numCols = num;
     }
     bool inRowSpan() const
     {
-      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->inRowSpan : FALSE;
+      return !m_tableStateStack.empty() ? m_tableStateStack.top().inRowSpan : FALSE;
     }
     void setInRowSpan(bool b)
     {
-      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->inRowSpan = b;
+      if (!m_tableStateStack.empty()) m_tableStateStack.top().inRowSpan = b;
     }
     bool inColSpan() const
     {
-      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->inColSpan : FALSE;
+      return !m_tableStateStack.empty() ? m_tableStateStack.top().inColSpan : FALSE;
     }
     void setInColSpan(bool b)
     {
-      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->inColSpan = b;
+      if (!m_tableStateStack.empty()) m_tableStateStack.top().inColSpan = b;
     }
     bool firstRow() const
     {
-      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->firstRow : FALSE;
+      return !m_tableStateStack.empty() ? m_tableStateStack.top().firstRow : FALSE;
     }
     void setFirstRow(bool b)
     {
-      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->firstRow = b;
+      if (!m_tableStateStack.empty()) m_tableStateStack.top().firstRow = b;
     }
-    const RowSpanList &rowSpans()
+    RowSpanList &rowSpans()
     {
-      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->rowSpans : m_emptyRowSpanList;
+      return !m_tableStateStack.empty() ? m_tableStateStack.top().rowSpans : m_emptyRowSpanList;
     }
-    void addRowSpan(ActiveRowSpan *span)
+    void addRowSpan(ActiveRowSpan &&span)
     {
-      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->rowSpans.append(span);
+      if (!m_tableStateStack.empty()) m_tableStateStack.top().rowSpans.push_back(std::move(span));
     }
     bool insideTable() const
     {
-      return !m_tableStateStack.isEmpty();
+      return !m_tableStateStack.empty();
     }
 
 };
