@@ -1,12 +1,12 @@
 /******************************************************************************
  *
- * 
+ *
  *
  * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -18,11 +18,15 @@
 #ifndef OUTPUTGEN_H
 #define OUTPUTGEN_H
 
-#include <qstack.h>
+#include <memory>
+#include <stack>
+#include <iostream>
+#include <fstream>
 
+#include "types.h"
 #include "index.h"
 #include "section.h"
-#include "ftextstream.h"
+#include "textstream.h"
 
 class ClassDiagram;
 class DotClassGraph;
@@ -33,9 +37,7 @@ class DotGfxHierarchyTable;
 class DotGroupCollaboration;
 class DocNode;
 class MemberDef;
-class GroupDef;
 class Definition;
-class QFile;
 
 struct DocLinkInfo
 {
@@ -54,31 +56,40 @@ struct SourceLinkInfo
   QCString anchor;
 };
 
-/** Output interface for code parser. 
+/** Output interface for code parser.
  */
 class CodeOutputInterface
 {
   public:
     virtual ~CodeOutputInterface() {}
+    CodeOutputInterface() {}
+    CodeOutputInterface(const CodeOutputInterface &) = delete;
+    CodeOutputInterface &operator=(const CodeOutputInterface &) = delete;
 
-    /*! Writes an code fragment to the output. This function should keep 
-     *  spaces visible, should break lines at a newline and should convert 
+    /** Identifier for the output file */
+    virtual int id() const { return 0; }
+
+    /*! Writes an code fragment to the output. This function should keep
+     *  spaces visible, should break lines at a newline and should convert
      *  tabs to the right number of spaces.
      */
-    virtual void codify(const char *s) = 0;
+    virtual void codify(const QCString &s) = 0;
 
     /*! Writes a link to an object in a code fragment.
+     *  \param type     The type of symbol, used for semantic syntax
+     *                  highlighting, may be Default is no info is available.
      *  \param ref      If this is non-zero, the object is to be found in
      *                  an external documentation file.
      *  \param file     The file in which the object is located.
-     *  \param anchor   The anchor uniquely identifying the object within 
-     *                  the file. 
+     *  \param anchor   The anchor uniquely identifying the object within
+     *                  the file.
      *  \param name     The text to display as a placeholder for the link.
      *  \param tooltip  The tooltip to display when the mouse is on the link.
      */
-    virtual void writeCodeLink(const char *ref,const char *file,
-                               const char *anchor,const char *name,
-                               const char *tooltip) = 0;
+    virtual void writeCodeLink(CodeSymbolType type,
+                               const QCString &ref,const QCString &file,
+                               const QCString &anchor,const QCString &name,
+                               const QCString &tooltip) = 0;
 
     /*! Writes the line number of a source listing
      *  \param ref        External reference (when imported from a tag file)
@@ -86,10 +97,10 @@ class CodeOutputInterface
      *  \param anchor     The anchor part of the URL pointing to the docs.
      *  \param lineNumber The line number to write
      */
-    virtual void writeLineNumber(const char *ref,const char *file,
-                                 const char *anchor,int lineNumber) = 0;
+    virtual void writeLineNumber(const QCString &ref,const QCString &file,
+                                 const QCString &anchor,int lineNumber) = 0;
 
-    /*! Writes a tool tip definition 
+    /*! Writes a tool tip definition
      *  \param id       unique identifier for the tooltip
      *  \param docInfo  Info about the symbol's documentation.
      *  \param decl     full declaration of the symbol (for functions)
@@ -97,14 +108,14 @@ class CodeOutputInterface
      *  \param defInfo  Info about the symbol's definition in the source code
      *  \param declInfo Info about the symbol's declaration in the source code
      */
-    virtual void writeTooltip(const char *id, 
+    virtual void writeTooltip(const QCString &id,
                               const DocLinkInfo &docInfo,
-                              const char *decl,
-                              const char *desc,
+                              const QCString &decl,
+                              const QCString &desc,
                               const SourceLinkInfo &defInfo,
                               const SourceLinkInfo &declInfo
                              ) = 0;
-                              
+
     virtual void startCodeLine(bool hasLineNumbers) = 0;
 
     /*! Ends a line of code started with startCodeLine() */
@@ -114,7 +125,7 @@ class CodeOutputInterface
      *  which elements of the same type are rendered using the same 'font class'.
      *  \param clsName The category name.
      */
-    virtual void startFontClass(const char *clsName) = 0;
+    virtual void startFontClass(const QCString &clsName) = 0;
 
     /*! Ends a block started with startFontClass() */
     virtual void endFontClass() = 0;
@@ -122,10 +133,20 @@ class CodeOutputInterface
     /*! Write an anchor to a source listing.
      *  \param name The name of the anchor.
      */
-    virtual void writeCodeAnchor(const char *name) = 0;
+    virtual void writeCodeAnchor(const QCString &name) = 0;
 
-    virtual void setCurrentDoc(const Definition *context,const char *anchor,bool isSourceFile) = 0;
-    virtual void addWord(const char *word,bool hiPriority) = 0;
+    virtual void setCurrentDoc(const Definition *context,const QCString &anchor,bool isSourceFile) = 0;
+    virtual void addWord(const QCString &word,bool hiPriority) = 0;
+
+    /*! Starts a source code fragment. The fragment will be
+     *  fed to the code parser (see code.h) for syntax highlighting
+     *  and cross-referencing. The fragment ends by a call to
+     *  endCodeFragment()
+     *  @param style The kind of code fragment.
+     */
+    virtual void startCodeFragment(const QCString &style) = 0;
+    /*! Ends a block of code */
+    virtual void endCodeFragment(const QCString &style) = 0;
 };
 
 /** Base Interface used for generating output outside of the
@@ -141,29 +162,29 @@ class BaseOutputDocInterface : public CodeOutputInterface
   public:
     virtual ~BaseOutputDocInterface() {}
     enum ParamListTypes { Param, RetVal, Exception };
-    enum SectionTypes { /*See, Return, Author, Version, 
+    enum SectionTypes { /*See, Return, Author, Version,
                         Since, Date, Bug, Note,
-                        Warning, Par, Deprecated, Pre, 
-                        Post, Invar, Remark, Attention, 
+                        Warning, Par, Deprecated, Pre,
+                        Post, Invar, Remark, Attention,
                         Todo, Test, RCS, */
-	                EnumValues, 
-                        Examples 
+	                EnumValues,
+                        Examples
                       };
 
-    virtual void parseText(const QCString &s) {}
-    
+    virtual void parseText(const QCString &) {}
+
     /*! Start of a bullet list: e.g. \c \<ul\> in html. startItemListItem() is
      *  Used for the bullet items.
      */
     virtual void startItemList()  = 0;
 
-    /*! Writes a list item for a bullet or enumerated 
-     *  list: e.g. \c \<li\> in html 
+    /*! Writes a list item for a bullet or enumerated
+     *  list: e.g. \c \<li\> in html
      */
     virtual void startItemListItem()  = 0;
 
-    /*! Writes a list item for a bullet or enumerated 
-     *  list: e.g. \c \</li\> in html 
+    /*! Writes a list item for a bullet or enumerated
+     *  list: e.g. \c \</li\> in html
      */
     virtual void endItemListItem()  = 0;
 
@@ -171,25 +192,25 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void endItemList()    = 0;
 
     /*! Writes an ASCII string to the output. Converts characters that have
-     *  A special meaning, like \c & in html. 
+     *  A special meaning, like \c & in html.
      */
-    virtual void docify(const char *s) = 0;
+    virtual void docify(const QCString &s) = 0;
 
     /*! Writes a single ASCII character to the output. Converts characters
      *  that have a special meaning.
      */
     virtual void writeChar(char c) = 0;
 
-    /*! Writes an ASCII string to the output, \e without converting 
-     *  special characters. 
+    /*! Writes an ASCII string to the output, \e without converting
+     *  special characters.
      */
-    virtual void writeString(const char *text) = 0;
+    virtual void writeString(const QCString &text) = 0;
 
     /*! Starts a new paragraph */
     //virtual void newParagraph()   = 0;
 
     /*! Starts a new paragraph */
-    virtual void startParagraph(const char *classDef) = 0;
+    virtual void startParagraph(const QCString &classDef) = 0;
     /*! Ends a paragraph */
     virtual void endParagraph() = 0;
 
@@ -197,24 +218,24 @@ class BaseOutputDocInterface : public CodeOutputInterface
      *  \param ref    If this is non-zero, the object is to be found in
      *                an external documentation file.
      *  \param file   The file in which the object is located.
-     *  \param anchor The anchor uniquely identifying the object within 
-     *                the file. 
+     *  \param anchor The anchor uniquely identifying the object within
+     *                the file.
      *  \param name   The text to display as a placeholder for the link.
      */
-    virtual void writeObjectLink(const char *ref,const char *file,
-                                 const char *anchor, const char *name) = 0;
+    virtual void writeObjectLink(const QCString &ref,const QCString &file,
+                                 const QCString &anchor, const QCString &name) = 0;
 
 
     /*! Starts a (link to an) URL found in the documentation.
      *  \param url    The URL to link to.
      */
-    virtual void startHtmlLink(const char *url) = 0;
+    virtual void startHtmlLink(const QCString &url) = 0;
 
     /*! Ends a link started by startHtmlLink().
      */
     virtual void endHtmlLink() = 0;
 
-    
+
     /*! Changes the text font to bold face. The bold section ends with
      *  endBold()
      */
@@ -239,24 +260,10 @@ class BaseOutputDocInterface : public CodeOutputInterface
     /*! Ends a section of text displayed in italic. */
     virtual void endEmphasis() = 0;
 
-    /*! Starts a source code fragment. The fragment will be
-     *  fed to the code parser (see code.h) for syntax highlighting
-     *  and cross-referencing. The fragment ends by a call to
-     *  endCodeFragment()
-     */
-    virtual void startCodeFragment() = 0;
-
-    /*! Ends a source code fragment
-     */
-    virtual void endCodeFragment() = 0;
-
-    
-
-    
     /*! Writes a horizontal ruler to the output */
     virtual void writeRuler() = 0;
-    
-    /*! Starts a description list: e.g. \c \<dl\> in HTML 
+
+    /*! Starts a description list: e.g. \c \<dl\> in HTML
      *  Items are surrounded by startDescItem() and endDescItem()
      */
     virtual void startDescription() = 0;
@@ -270,8 +277,8 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void startDescForItem() = 0;
     virtual void endDescForItem() = 0;
 
-    /*! Ends an item of a description list and starts the 
-     *  description itself: e.g. \c \</dt\> in HTML. 
+    /*! Ends an item of a description list and starts the
+     *  description itself: e.g. \c \</dt\> in HTML.
      */
     virtual void endDescItem() = 0;
 
@@ -282,22 +289,22 @@ class BaseOutputDocInterface : public CodeOutputInterface
 
     virtual void startExamples() = 0;
     virtual void endExamples() = 0;
-    virtual void startParamList(ParamListTypes t,const char *title) = 0;
+    virtual void startParamList(ParamListTypes t,const QCString &title) = 0;
     virtual void endParamList() = 0;
 
     //virtual void writeDescItem() = 0;
     virtual void startTitle() = 0;
     virtual void endTitle()   = 0;
 
-    virtual void writeAnchor(const char *fileName,const char *name) = 0;
-    virtual void startSection(const char *,const char *,SectionInfo::SectionType) = 0;
-    virtual void endSection(const char *,SectionInfo::SectionType) = 0;
+    virtual void writeAnchor(const QCString &fileName,const QCString &name) = 0;
+    virtual void startSection(const QCString &,const QCString &,SectionType) = 0;
+    virtual void endSection(const QCString &,SectionType) = 0;
 
-    virtual void lineBreak(const char *style) = 0;
-    virtual void addIndexItem(const char *s1,const char *s2) = 0;
+    virtual void lineBreak(const QCString &style) = 0;
+    virtual void addIndexItem(const QCString &s1,const QCString &s2) = 0;
 
     virtual void writeNonBreakableSpace(int) = 0;
-    virtual void startDescTable(const char *title) = 0;
+    virtual void startDescTable(const QCString &title) = 0;
     virtual void endDescTable() = 0;
     virtual void startDescTableRow() = 0;
     virtual void endDescTableRow() = 0;
@@ -305,10 +312,10 @@ class BaseOutputDocInterface : public CodeOutputInterface
     virtual void endDescTableTitle() = 0;
     virtual void startDescTableData() = 0;
     virtual void endDescTableData() = 0;
-    virtual void startTextLink(const char *file,const char *anchor) = 0;
+    virtual void startTextLink(const QCString &file,const QCString &anchor) = 0;
     virtual void endTextLink() = 0;
     virtual void startPageRef() = 0;
-    virtual void endPageRef(const char *,const char *) = 0;
+    virtual void endPageRef(const QCString &,const QCString &) = 0;
     virtual void startSubsection() = 0;
     virtual void endSubsection() = 0;
     virtual void startSubsubsection() = 0;
@@ -324,46 +331,54 @@ class OutputGenerator : public BaseOutputDocInterface
   public:
     enum OutputType { Html, Latex, Man, RTF, XML, DEF, Perl , Docbook};
 
-    OutputGenerator();
+    OutputGenerator(const QCString &dir);
+    OutputGenerator(const OutputGenerator &o);
+    OutputGenerator &operator=(const OutputGenerator &o);
     virtual ~OutputGenerator();
 
+    virtual OutputType type() const = 0;
+    virtual std::unique_ptr<OutputGenerator> clone() const = 0;
+
     ///////////////////////////////////////////////////////////////
     // generic generator methods
     ///////////////////////////////////////////////////////////////
-    virtual void enable() = 0;
-    virtual void disable() = 0;
-    virtual void enableIf(OutputType o) = 0;
-    virtual void disableIf(OutputType o) = 0;
-    virtual void disableIfNot(OutputType o) = 0;
-    virtual bool isEnabled(OutputType o) = 0;
-    virtual OutputGenerator *get(OutputType o) = 0;
-    void startPlainFile(const char *name);
+    void enable();
+    void disable();
+    void enableIf(OutputType o);
+    void disableIf(OutputType o);
+    void disableIfNot(OutputType o);
+    bool isEnabled(OutputType o);
+    OutputGenerator *get(OutputType o);
+    QCString dir() const;
+    QCString fileName() const;
+
+    void startPlainFile(const QCString &name);
     void endPlainFile();
     //QCString getContents() const;
-    bool isEnabled() const { return active; }
+    bool isEnabled() const { return m_active; }
     void pushGeneratorState();
     void popGeneratorState();
     //void setEncoding(const QCString &enc) { encoding = enc; }
     //virtual void postProcess(QByteArray &) { }
 
-    virtual void writeDoc(DocNode *,const Definition *ctx,const MemberDef *md) = 0;
+    virtual void writeDoc(DocNode *,const Definition *ctx,const MemberDef *md,int id) = 0;
 
     ///////////////////////////////////////////////////////////////
     // structural output interface
     ///////////////////////////////////////////////////////////////
-    virtual void startFile(const char *name,const char *manName,
-                           const char *title) = 0;
+    virtual void startFile(const QCString &name,const QCString &manName,
+                           const QCString &title,int id=0) = 0;
     virtual void writeSearchInfo() = 0;
-    virtual void writeFooter(const char *navPath) = 0;
+    virtual void writeFooter(const QCString &navPath) = 0;
     virtual void endFile() = 0;
     virtual void startIndexSection(IndexSections) = 0;
     virtual void endIndexSection(IndexSections) = 0;
-    virtual void writePageLink(const char *,bool) = 0;
+    virtual void writePageLink(const QCString &,bool) = 0;
     virtual void startProjectNumber() = 0;
     virtual void endProjectNumber() = 0;
     virtual void writeStyleInfo(int part) = 0;
-    virtual void startTitleHead(const char *) = 0;
-    virtual void endTitleHead(const char *fileName,const char *name) = 0;
+    virtual void startTitleHead(const QCString &) = 0;
+    virtual void endTitleHead(const QCString &fileName,const QCString &name) = 0;
     virtual void startIndexListItem() = 0;
     virtual void endIndexListItem()   = 0;
     virtual void startIndexList() = 0;
@@ -371,16 +386,16 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void startIndexKey() = 0;
     virtual void endIndexKey()   = 0;
     virtual void startIndexValue(bool) = 0;
-    virtual void endIndexValue(const char *,bool) = 0;
-    virtual void startIndexItem(const char *ref,const char *file) = 0;
-    virtual void endIndexItem(const char *ref,const char *file) = 0;
+    virtual void endIndexValue(const QCString &,bool) = 0;
+    virtual void startIndexItem(const QCString &ref,const QCString &file) = 0;
+    virtual void endIndexItem(const QCString &ref,const QCString &file) = 0;
     virtual void startGroupHeader(int) = 0;
     virtual void endGroupHeader(int) = 0;
     virtual void startMemberSections() = 0;
     virtual void endMemberSections() = 0;
     virtual void startHeaderSection() = 0;
     virtual void endHeaderSection() = 0;
-    virtual void startMemberHeader(const char *anchor, int typ) = 0;
+    virtual void startMemberHeader(const QCString &anchor, int typ) = 0;
     virtual void endMemberHeader() = 0;
     virtual void startMemberSubtitle() = 0;
     virtual void endMemberSubtitle() = 0;
@@ -392,10 +407,12 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endInlineHeader() = 0;
     virtual void startAnonTypeScope(int) = 0;
     virtual void endAnonTypeScope(int) = 0;
-    virtual void startMemberItem(const char *,int,const char *) = 0;
+    virtual void startMemberItem(const QCString &,int,const QCString &) = 0;
     virtual void endMemberItem() = 0;
     virtual void startMemberTemplateParams() = 0;
-    virtual void endMemberTemplateParams(const char *,const char *) = 0;
+    virtual void endMemberTemplateParams(const QCString &,const QCString &) = 0;
+    virtual void startCompoundTemplateParams() = 0;
+    virtual void endCompoundTemplateParams() = 0;
     virtual void startMemberGroupHeader(bool) = 0;
     virtual void endMemberGroupHeader() = 0;
     virtual void startMemberGroupDocs() = 0;
@@ -404,29 +421,29 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberGroup(bool) = 0;
     virtual void insertMemberAlign(bool) = 0;
     virtual void insertMemberAlignLeft(int,bool) = 0;
-    virtual void startMemberDoc(const char *,const char *,
-                                const char *,const char *,int,int,bool) = 0;
+    virtual void startMemberDoc(const QCString &,const QCString &,
+                                const QCString &,const QCString &,int,int,bool) = 0;
     virtual void endMemberDoc(bool) = 0;
-    virtual void startDoxyAnchor(const char *fName,const char *manName,
-                                 const char *anchor,const char *name,
-                                 const char *args) = 0;
-    virtual void endDoxyAnchor(const char *fileName,const char *anchor) = 0;
+    virtual void startDoxyAnchor(const QCString &fName,const QCString &manName,
+                                 const QCString &anchor,const QCString &name,
+                                 const QCString &args) = 0;
+    virtual void endDoxyAnchor(const QCString &fileName,const QCString &anchor) = 0;
     virtual void writeLatexSpacing() = 0;
-    virtual void writeStartAnnoItem(const char *type,const char *file,
-                                    const char *path,const char *name) = 0;
-    virtual void writeEndAnnoItem(const char *name) = 0;
-    virtual void startMemberDescription(const char *anchor,const char *inheritId, bool typ) = 0;
+    virtual void writeStartAnnoItem(const QCString &type,const QCString &file,
+                                    const QCString &path,const QCString &name) = 0;
+    virtual void writeEndAnnoItem(const QCString &name) = 0;
+    virtual void startMemberDescription(const QCString &anchor,const QCString &inheritId, bool typ) = 0;
     virtual void endMemberDescription() = 0;
     virtual void startMemberDeclaration() = 0;
-    virtual void endMemberDeclaration(const char *anchor,const char *inheritId) = 0;
-    virtual void writeInheritedSectionTitle(const char *id,const char *ref,
-                                            const char *file,const char *anchor,
-                                            const char *title,const char *name) = 0;
+    virtual void endMemberDeclaration(const QCString &anchor,const QCString &inheritId) = 0;
+    virtual void writeInheritedSectionTitle(const QCString &id,const QCString &ref,
+                                            const QCString &file,const QCString &anchor,
+                                            const QCString &title,const QCString &name) = 0;
     virtual void startIndent() = 0;
     virtual void endIndent() = 0;
     virtual void writeSynopsis() = 0;
     virtual void startClassDiagram() = 0;
-    virtual void endClassDiagram(const ClassDiagram &,const char *,const char *) = 0;
+    virtual void endClassDiagram(const ClassDiagram &,const QCString &,const QCString &) = 0;
     virtual void startDotGraph() = 0;
     virtual void endDotGraph(DotClassGraph &g) = 0;
     virtual void startInclDepGraph() = 0;
@@ -440,15 +457,15 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void writeGraphicalHierarchy(DotGfxHierarchyTable &g) = 0;
     virtual void startQuickIndices() = 0;
     virtual void endQuickIndices() = 0;
-    virtual void writeSplitBar(const char *) = 0;
-    virtual void writeNavigationPath(const char *) = 0;
+    virtual void writeSplitBar(const QCString &) = 0;
+    virtual void writeNavigationPath(const QCString &) = 0;
     virtual void writeLogo() = 0;
-    virtual void writeQuickLinks(bool compact,HighlightedItem hli,const char *file) = 0;
-    virtual void writeSummaryLink(const char *file,const char *anchor,const char *title,bool first) = 0;
+    virtual void writeQuickLinks(bool compact,HighlightedItem hli,const QCString &file) = 0;
+    virtual void writeSummaryLink(const QCString &file,const QCString &anchor,const QCString &title,bool first) = 0;
     virtual void startContents() = 0;
     virtual void endContents() = 0;
-    virtual void startPageDoc(const char *pageTitle) {};
-    virtual void endPageDoc() {};
+    virtual void startPageDoc(const QCString &) {}
+    virtual void endPageDoc() {}
     virtual void startTextBlock(bool) = 0;
     virtual void endTextBlock(bool) = 0;
     virtual void lastIndexPage() = 0;
@@ -456,15 +473,15 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberDocPrefixItem() = 0;
     virtual void startMemberDocName(bool) = 0;
     virtual void endMemberDocName() = 0;
-    virtual void startParameterType(bool,const char *key) = 0;
+    virtual void startParameterType(bool,const QCString &key) = 0;
     virtual void endParameterType() = 0;
     virtual void startParameterName(bool) = 0;
     virtual void endParameterName(bool,bool,bool) = 0;
     virtual void startParameterList(bool) = 0;
     virtual void endParameterList() = 0;
-    virtual void exceptionEntry(const char*,bool) = 0;
+    virtual void exceptionEntry(const QCString &,bool) = 0;
 
-    virtual void startConstraintList(const char *) = 0;
+    virtual void startConstraintList(const QCString &) = 0;
     virtual void startConstraintParam() = 0;
     virtual void endConstraintParam() = 0;
     virtual void startConstraintType() = 0;
@@ -484,26 +501,25 @@ class OutputGenerator : public BaseOutputDocInterface
 
 
     virtual void startLabels() = 0;
-    virtual void writeLabel(const char *,bool) = 0;
+    virtual void writeLabel(const QCString &,bool) = 0;
     virtual void endLabels() = 0;
 
-  protected:
-    FTextStream t;
-    QFile *file;
-    QCString fileName;
-    QCString dir;
-    bool active;
-    QStack<bool> *genStack;
+    virtual void cleanup() = 0;
 
+  protected:
+    TextStream m_t;
   private:
-    OutputGenerator(const OutputGenerator &o);
-    OutputGenerator &operator=(const OutputGenerator &o);
+    QCString m_dir;
+    QCString m_fileName;
+    FILE *m_file;
+    bool m_active = true;
+    std::stack<bool> m_genStack;
 };
 
 /** Interface used for generating documentation.
  *
  *  This abstract class is used by several functions
- *  to generate the output for a specific format. 
+ *  to generate the output for a specific format.
  *  This interface contains some state saving and changing
  *  functions for dealing with format specific output.
  */
@@ -512,18 +528,13 @@ class OutputDocInterface : public BaseOutputDocInterface
   public:
     virtual ~OutputDocInterface() {}
 
-    /*! Create a new output generator. This can later by appended
-     *  to the current one using append().
-     */
-    //virtual OutputDocInterface *clone() = 0;
-
-    /*! Disables all output formats except format \a o 
-     *  (useful for OutputList only) 
+    /*! Disables all output formats except format \a o
+     *  (useful for OutputList only)
      */
     virtual void disableAllBut(OutputGenerator::OutputType o) = 0;
 
     /*! Enables all output formats as far as they have been enabled in
-     *  the config file. (useful for OutputList only) 
+     *  the config file. (useful for OutputList only)
      */
     virtual void enableAll() = 0;
 
@@ -536,27 +547,26 @@ class OutputDocInterface : public BaseOutputDocInterface
     /*! Enables a specific output format (useful for OutputList only) */
     virtual void enable(OutputGenerator::OutputType o) = 0;
 
-    /*! Check whether a specific output format is currently enabled 
-     *  (useful for OutputList only) 
+    /*! Check whether a specific output format is currently enabled
+     *  (useful for OutputList only)
      */
     virtual bool isEnabled(OutputGenerator::OutputType o) = 0;
 
     /*! Appends the output generated by generator \a g to this
      *  generator.
-     */ 
+     */
     //virtual void append(const OutputDocInterface *g) = 0;
 
-    /*! Pushes the state of the current generator (or list of 
+    /*! Pushes the state of the current generator (or list of
      *  generators) on a stack.
      */
     virtual void pushGeneratorState() = 0;
 
-    /*! Pops the state of the current generator (or list of 
+    /*! Pops the state of the current generator (or list of
      *  generators) on a stack. Should be preceded by a call
      *  the pushGeneratorState().
      */
     virtual void popGeneratorState() = 0;
 };
 
-
 #endif
