@@ -135,6 +135,11 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
              "\\NoAutoSpaceBeforeFDP\n";
     }
 
+    virtual QCString trISOLang()
+    {
+      return "fr";
+    }
+
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -197,9 +202,9 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Généré automatiquement par Doxygen";
-      if (s) result+=(QCString)" pour "+s;
+      if (!s.isEmpty()) result+=(QCString)" pour "+s;
       result+=" à partir du code source.";
       return result;
     }
@@ -564,16 +569,16 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
       QCString result=(QCString)"Généré le "+date;
-      if (projName) result+=(QCString)" pour "+projName;
+      if (!projName.isEmpty()) result+=(QCString)" pour "+projName;
       result+=(QCString)" par";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
       return (QCString)"Graphe d'héritage de "+clName+":";
     }
@@ -652,7 +657,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -675,7 +680,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result= "Référence du fichier ";
       result+=fileName;
@@ -683,7 +688,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result= "Référence de l'espace de nommage ";
       result+=namespaceName;
@@ -883,12 +888,12 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
       return (QCString)"Graphe de collaboration de "+clName+":";
     }
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
       return (QCString)"Graphe des dépendances par inclusion de "+fName+":";
     }
@@ -1168,7 +1173,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
       }
     }
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
       return (QCString)"Paquetage "+name;
     }
@@ -1563,7 +1568,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString  result="Répertoire de référence de "; result+=dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1690,7 +1695,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -1711,7 +1716,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result="Référence du module ";
       result+= namespaceName;
@@ -1813,7 +1818,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return "Relation " + QCString(name);
     }
@@ -1850,7 +1855,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
       return (QCString)"Fichier dans "+name;
     }
@@ -1859,7 +1864,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
       return (QCString)"Inclut le fichier dans "+name;
     }
@@ -1904,7 +1909,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Graphe des dépendances de répertoires pour ")+name+":"; }
 
 
@@ -1933,11 +1938,11 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" Référence de l'énumération"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" hérités de "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -2001,14 +2006,6 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
       return "Documentation des méthodes";
     }
 
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
-    {
-      return "Vue d'ensemble";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.8.4
 //////////////////////////////////////////////////////////////////////////
@@ -2026,21 +2023,21 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     { return "Groupes constants"; }
 
     /** UNO IDL constant groups */
-    virtual QCString trConstantGroupReference(const char *namespaceName)
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
       QCString result="Référence du groupe constant ";
       result+=namespaceName;
       return result;
     }
     /** UNO IDL service page title */
-    virtual QCString trServiceReference(const char *sName)
+    virtual QCString trServiceReference(const QCString &sName)
     {
       QCString result="Référence du service ";
       result+=(QCString)sName;
       return result;
     }
     /** UNO IDL singleton page title */
-    virtual QCString trSingletonReference(const char *sName)
+    virtual QCString trSingletonReference(const QCString &sName)
     {
       QCString result="Référence du singleton ";
       result+=(QCString)sName;
@@ -2179,7 +2176,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
           return "Classe";
       }
     }
-    virtual QCString trCustomReference(const char *name)
+    virtual QCString trCustomReference(const QCString &name)
     { return QCString("Référence ") + QCString(name); }
 
     virtual QCString trConstants()
@@ -2278,7 +2275,7 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
     {
         return "Documentation des exceptions";
     }
-    virtual QCString trCompoundReferenceSlice(const char *clName, ClassDef::CompoundType compType, bool isLocal)
+    virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
     {
       QCString result = "Référence ";
       bool feminine = true;
@@ -2320,8 +2317,6 @@ class TranslatorFrench : public TranslatorAdapter_1_8_15
         return "Documentation des champs de données";
     }
 
-//////////////////////////////////////////////////////////////////////////
-
 };
 
 #endif
